# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nlit',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/nlit',
                'lib_path': 'nlit'},
  'syms': { 'nlit.args': {},
            'nlit.biol': {},
            'nlit.bkts': {},
            'nlit.byte': {},
            'nlit.cell': {},
            'nlit.clrs': {},
            'nlit.docs': {},
            'nlit.dund': {},
            'nlit.embs': {},
            'nlit.exps': {},
            'nlit.exts': {},
            'nlit.mods': {},
            'nlit.mthd': {},
            'nlit.narr': {},
            'nlit.nbks': {},
            'nlit.path': {},
            'nlit.plot': {},
            'nlit.sund': {},
            'nlit.tens': {},
            'nlit.tree': {},
            'nlit.unit': {}}}
