# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'SEP', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SPEC', 'SPECS', 'DEBUG', 'VALUE', 'CUTOFF', 'MIXINS',
           'UNIQUE', 'INPLACE', 'VERBOSE', 'OPTIONAL', 'REQUIRED', 'ASMEMBER', 'ABRV', 'SYMB', 'BEG', 'END', 'POS',
           'NEG', 'LEN', 'DIG', 'BRV', 'FIX']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
SEP = 'sep'

# %% ../nbs/02_args.ipynb 7
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'

# %% ../nbs/02_args.ipynb 8
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 9
DEBUG = 'debug'
VALUE = 'value'

# %% ../nbs/02_args.ipynb 10
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 11
INPLACE = 'inplace'
VERBOSE = 'verbose'

# %% ../nbs/02_args.ipynb 12
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 14
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 16
ABRV = 'abrv'
SYMB = 'symb'

# %% ../nbs/02_args.ipynb 19
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix
